summaryrefslogtreecommitdiff
path: root/ext/cpdf
diff options
context:
space:
mode:
authorUwe Steinmann <steinm@php.net>2000-01-10 12:42:05 +0000
committerUwe Steinmann <steinm@php.net>2000-01-10 12:42:05 +0000
commit78e84f9da3f68d0a7ce153e72a9a593399081c2c (patch)
tree7fb39f66f08e8d9292943f2128f5a5411f2983a1 /ext/cpdf
parenta4dc650d11bb6174c44784c036339f6bf8addd6b (diff)
downloadphp-git-78e84f9da3f68d0a7ce153e72a9a593399081c2c.tar.gz
- changed cpdf_global_set_document_settings() to cpdf_global_set_document_limits()
Diffstat (limited to 'ext/cpdf')
-rw-r--r--ext/cpdf/cpdf.c6
-rw-r--r--ext/cpdf/php_cpdf.h2
2 files changed, 4 insertions, 4 deletions
diff --git a/ext/cpdf/php_cpdf.h b/ext/cpdf/php_cpdf.h
index 8c3dde4755..517c018944 100644
--- a/ext/cpdf/php_cpdf.h
+++ b/ext/cpdf/php_cpdf.h
@@ -42,7 +42,7 @@ extern PHP_MINFO_FUNCTION(cpdf);
extern PHP_MINIT_FUNCTION(cpdf);
extern PHP_RINIT_FUNCTION(cpdf);
extern PHP_MSHUTDOWN_FUNCTION(cpdf);
-PHP_FUNCTION(cpdf_global_set_documents_settings);
+PHP_FUNCTION(cpdf_global_set_document_limits);
PHP_FUNCTION(cpdf_set_creator);
PHP_FUNCTION(cpdf_set_title);
PHP_FUNCTION(cpdf_set_subject);
diff --git a/ext/cpdf/cpdf.c b/ext/cpdf/cpdf.c
index c334503208..404bc5001f 100644
--- a/ext/cpdf/cpdf.c
+++ b/ext/cpdf/cpdf.c
@@ -76,7 +76,7 @@ static int le_outline;
#endif
function_entry cpdf_functions[] = {
- PHP_FE(cpdf_global_set_documents_settings, NULL)
+ PHP_FE(cpdf_global_set_document_limits, NULL)
PHP_FE(cpdf_set_creator, NULL)
PHP_FE(cpdf_set_title, NULL)
PHP_FE(cpdf_set_subject, NULL)
@@ -191,9 +191,9 @@ PHP_MSHUTDOWN_FUNCTION(cpdf){
return SUCCESS;
}
/* {{{ proto void cpdf_global_set_document_settings(int maxPages, int maxFonts, int maxImages, int maxAnnots, int maxObjects)
Sets document settings for all documents */
-PHP_FUNCTION(cpdf_global_set_documents_settings) {
+PHP_FUNCTION(cpdf_global_set_document_limits) {
pval *argv[5];
int argc;
CPDF_TLS_VARS;
@@ -191,9 +191,9 @@ PHP_MSHUTDOWN_FUNCTION(cpdf){
return SUCCESS;
}
-/* {{{ proto void cpdf_global_set_document_settings(int maxPages, int maxFonts, int maxImages, int maxAnnots, int maxObjects)
+/* {{{ proto void cpdf_global_set_document_limits(int maxPages, int maxFonts, int maxImages, int maxAnnots, int maxObjects)
Sets document settings for all documents */